# ![splashsurf logo](https://raw.githubusercontent.com/InteractiveComputerGraphics/splashsurf/main/logos/logo_small.svg "splashsurf")

This is a placeholder for the Python bindings to splashsurf, an open source surface reconstruction library for particle data from SPH simulations.
In the meantime, please refer to the [project website (splashsurf.physics-simulation.org)](https://splashsurf.physics-simulation.org/) or the [main repository](https://github.com/InteractiveComputerGraphics/splashsurf) for more information.
